=============
Miscellaneous
=============

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    DataFrame.collect_schema
    DataFrame.corr
    DataFrame.equals
    DataFrame.lazy
    DataFrame.map_rows

Serialization
-------------

.. autosummary::
   :toctree: api/

    DataFrame.deserialize
    DataFrame.serialize
